/*
	rootdir.h (09.11.10)
	Root directory creation code.

	Copyright (C) 2011-2013  Andrew Nayenko

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MKFS_ROOTDIR_H_INCLUDED
#define MKFS_ROOTDIR_H_INCLUDED

#include "mkexfat.h"

extern const struct fs_object rootdir;

#endif /* ifndef MKFS_ROOTDIR_H_INCLUDED */
